@@ -377,7 +377,7 @@ flames_load_ordef(const cpl_frameset *frames, const char *chip_name,
   @brief    Load a table
   @param    frames    The input frameset
   @param    filename  File containing the table
-  @param    extention The table extention
+  @param    extension The table extension
   @param    table     Loaded table
   @param    pheader   Loaded primary header, if non-NULL
   @param    theader   Loaded table header, if non-NULL
@@ -394,7 +394,7 @@ flames_load_table(const cpl_frameset *frames,
           cpl_table **table, 
           uves_propertylist **pheader,
           uves_propertylist **theader,
-          const int extention, 
+          const int extension, 
           const char* tag)
 {
     const char *tags[1];
@@ -408,16 +408,16 @@ flames_load_table(const cpl_frameset *frames,
     
     /* Load table */
     check( *table = cpl_table_load(*filename,
-                   extention,
+                   extension,
                        1),         /* Mark identified 
                               invalid values? (1=yes) */
        "Error loading line reference table from extension %d of file '%s'", 
-       extention, *filename);
+       extension, *filename);
 
    
     if(uves_erase_invalid_table_rows(*table, NULL) > 0) { 
       uves_msg_warning("Table in extension %d of file '%s' "
-                       "contains invalid rows", extention, *filename);
+                       "contains invalid rows", extension, *filename);
     }
 
     /* Load headers if requested */
@@ -452,7 +452,7 @@ flames_load_table(const cpl_frameset *frames,
   @param    raw_image      (output) The loaded image(s)
   @param    raw_header     (output) The raw image header(s)
   @param    rotated_header (output) Header(s) containing the proper CDELT, CRPIX... 
-  @param    ext_tbl (output) Extention table with FIBER mode info. 
+  @param    ext_tbl (output) Extension table with FIBER mode info. 
 
   @return   CPL_ERROR_NONE iff OK
 
