@@ -180,7 +180,7 @@ const char *flames_fileutils_tilde_replace (const char * name)
       if (len > (PATHSET_MAX-1))
 	{
 	  cpl_msg_error (cpl_func, "Buffer overflow in filename '%s' - fatal error", name);
-	  exit (EXIT_FAILURE);
+	  abort();
 	}
       (void) strcpy (str, name);
     }
@@ -191,7 +191,7 @@ const char *flames_fileutils_tilde_replace (const char * name)
       if (cpp == NULL)
 	{
 	  cpl_msg_error (cpl_func, "Env. variable HOME not set, could not replace `~'");
-	  exit (EXIT_FAILURE);
+	  abort();
 	}
        
       (void) strcpy (str,cpp);
@@ -199,7 +199,7 @@ const char *flames_fileutils_tilde_replace (const char * name)
       if (len > PATHSET_MAX)                /* -1 for (name+1) below */
 	{
 	  cpl_msg_error (cpl_func, "Buffer overflow in filename '%s' - fatal error", name);
-	  exit (EXIT_FAILURE);
+	  abort();
 	}
 
       (void) strcat (str, name + 1);
@@ -274,7 +274,7 @@ const char *flames_fileutils_dot_replace (const char * name)
       if (len > (PATHSET_MAX-1))
 	{
 	  cpl_msg_error (cpl_func, "Buffer overflow in filename '%s' - fatal error", name);
-	  exit (EXIT_FAILURE);
+	  abort();
 	}
 
       (void) strcpy (str, name);
@@ -291,7 +291,7 @@ const char *flames_fileutils_dot_replace (const char * name)
       if (len > (PATHSET_MAX-1))
 	{
 	  cpl_msg_error (cpl_func, "Buffer overflow in filename '%s' - fatal error", name);
-	  exit (EXIT_FAILURE);
+	  abort();
 	}
 
       (void) strcpy (str,cpp);
@@ -299,7 +299,7 @@ const char *flames_fileutils_dot_replace (const char * name)
   else
     {
       cpl_msg_error (cpl_func, "Env. variable PWD not set - fatal errorn");
-      exit (EXIT_FAILURE);
+      abort();
     }
 
 
@@ -310,7 +310,7 @@ const char *flames_fileutils_dot_replace (const char * name)
       if ((len+2) > (PATHSET_MAX-1))
 	{
 	  cpl_msg_error (cpl_func, "Buffer overflow in filename '%s' - fatal error", name);
-	  exit (EXIT_FAILURE);
+	  abort();
 	}
       (void) strcat (str, "/.");
       len += 2;
@@ -322,7 +322,7 @@ const char *flames_fileutils_dot_replace (const char * name)
       cpl_msg_error (cpl_func, "Buffer overflow in filename '%s'", name);
       cpl_msg_error (cpl_func, "Fatal error replacing current working "
 		     "directory symbol due to buffer overflow");
-      exit (EXIT_FAILURE);
+      abort();
     }
   (void) strcat(str, name + 1);        /* Add the rest of the file name */
 
