@@ -346,6 +346,7 @@ fillholes(
     for (ix=0; ix<=(allflatsin->subcols-1); ix++) {
       if ((status=calcfillshifts(allflatsin, shiftbuffer, ix)) 
           != NOERR) {
+          free(shiftdata);
         return(status);
       }
     }
@@ -747,7 +748,7 @@ fillholes(
 
                         if ( strcmp(drs_verbosity,"LOW") == 0 ){
                         } else {
-                          sprintf(output,drs_id);
+			  sprintf(output, "%s", drs_id);
                           SCTPUT(output);
                           SCTPUT("Warning: interpolated large negative value:");
                           sprintf(output, "pixel=%g and sigma=%g at x=%d, \
@@ -1079,7 +1080,7 @@ y=%d", pixelvalue, pixelsigma, ix+1, iy+1);
 
                         if ( strcmp(drs_verbosity,"LOW") == 0 ) {
                         } else {
-                          sprintf(output,drs_id);
+			  sprintf(output, "%s", drs_id);
                           SCTPUT(output);
                           SCTPUT("Warning: interpolated large negative value:");
                           sprintf(output, "pixel=%g and sigma=%g at x=%d, \
@@ -1105,7 +1106,7 @@ y=%d", pixelvalue, pixelsigma, ix+1, iy+1);
 
                       if ( strcmp(drs_verbosity,"LOW") == 0 ) {
                       } else {
-                        sprintf(output,drs_id);
+			sprintf(output, "%s", drs_id);
                         SCTPUT(output);
                         SCTPUT("Warning: interpolated too large normalised \
 value:");
@@ -1250,7 +1251,7 @@ y=%d", pixelvalue, pixelsigma, ix+1, iy+1);
         /* we were unable to find any good slice for this fibre, discard it */
         allflatsin->fibremask[ifibre] = FALSE;
         ordpos->fibremask[ifibre] = FALSE;
-        sprintf(output,drs_id);
+        sprintf(output, "%s", drs_id);
         SCTPUT(output);
         sprintf(output, "fracslices=%f Warning: ignoring fibre %d which has poor coverage",
             fracslices,ifibre+1);
