@@ -576,6 +576,9 @@ BKGBADSCAN");
   if ((status=SCKRDD(SIGMA, 1, 1, &actvals, &kappa, &unit, &null))!=0) {
     /* something went wrong while reading the kappa-sigma factor */
     SCTPUT("Error while reading SIGMA keyword");
+    free(myflats);
+    free(framebuffer);
+    free(ordpos);
     return flames_midas_fail();
   }
   /* compute once and for all the square of kappa, as we will be using that */
