@@ -750,7 +750,7 @@ static void recipe_sof_test_image_empty(cpl_plugin * plugin, size_t nstr,
     cpl_frameset * copy;
     cpl_error_code error;
     size_t i;
-    cpl_frame * frame;
+    const cpl_frame * frame;
     cpl_image * iempty;
     int retstat;
 
@@ -792,6 +792,7 @@ static void recipe_sof_test_image_empty(cpl_plugin * plugin, size_t nstr,
     cpl_test(recipe_exec != NULL);
 
     if (recipe_exec != NULL) {
+        cpl_frameset_iterator * iterator = NULL;
 
         /* Call recipe and expect consistency between return code and
            CPL error */
@@ -808,11 +809,13 @@ static void recipe_sof_test_image_empty(cpl_plugin * plugin, size_t nstr,
 
         recipe_frameset_test_frameset_diff(recipe->frames, copy);
 
-        for (frame = cpl_frameset_get_first(recipe->frames); frame != NULL;
-             frame = cpl_frameset_get_next(recipe->frames))
+        for (frame = irplib_frameset_get_first_const(&iterator, recipe->frames);
+             frame != NULL;
+             frame = irplib_frameset_get_next_const(iterator))
             {
                 cpl_test_zero( remove(cpl_frame_get_filename(frame)) );
             }
+        cpl_frameset_iterator_delete(iterator);
 
         recipe_frameset_empty(recipe->frames);
     }
@@ -853,7 +856,7 @@ cpl_boolean irplib_plugin_has_sof_from_env(const cpl_plugin * plugin,
     frames = cpl_frameset_new();
     recipe_frameset_load(frames, sof_name);
 
-    ffirst = cpl_frameset_get_first_const(frames);
+    ffirst = cpl_frameset_get_position_const(frames, 0);
 
     cpl_free(sof_name);
     cpl_frameset_delete(frames);
@@ -1147,16 +1150,17 @@ const cpl_parameter * irplib_parameterlist_get(const cpl_parameterlist * self,
 /*----------------------------------------------------------------------------*/
 static void recipe_frameset_empty(cpl_frameset * self)
 {
-    cpl_frame * f;
+    cpl_size i, n;
 
     if (self == NULL) {
         cpl_error_set(cpl_func, CPL_ERROR_NULL_INPUT);
         return;
     }
 
-    for (f = cpl_frameset_get_first(self); f != NULL;
-         f = cpl_frameset_get_first(self))
+    n = cpl_frameset_get_size(self);
+    for (i = 0; i < n; ++i)
         {
+            cpl_frame * f = cpl_frameset_get_position(self, n-1-i);
             cpl_frameset_erase_frame(self, f);
         }
 }
@@ -1232,10 +1236,12 @@ static void recipe_frameset_test_frameset_diff(const cpl_frameset * self,
                                                const cpl_frameset * other)
 {
 
-    const cpl_frame * frame = cpl_frameset_get_first_const(other);
+    cpl_frameset_iterator * it1 = NULL;
+    cpl_frameset_iterator * it2 = NULL;
+    const cpl_frame * frame = irplib_frameset_get_first_const(&it2, other);
 
     /* First verify that filenames in other are non-NULL */
-    for (;frame != NULL; frame = cpl_frameset_get_next_const(other)) {
+    for (;frame != NULL; frame = irplib_frameset_get_next_const(it2)) {
         const char * file = cpl_frame_get_filename(frame);
 
         if (file == NULL) {
@@ -1243,12 +1249,14 @@ static void recipe_frameset_test_frameset_diff(const cpl_frameset * self,
             break;
         }
     }
+    cpl_frameset_iterator_delete(it2);
+    it2 = NULL;
     if (frame != NULL) return;
 
-    frame = cpl_frameset_get_first_const(self);
+    frame = irplib_frameset_get_first_const(&it1, self);
 
-    for (;frame != NULL; frame = cpl_frameset_get_next_const(self)) {
-        const cpl_frame * cmp  = cpl_frameset_get_first_const(other);
+    for (;frame != NULL; frame = irplib_frameset_get_next_const(it1)) {
+        const cpl_frame * cmp;
         const char * file = cpl_frame_get_filename(frame);
 
         if (file == NULL) {
@@ -1256,12 +1264,15 @@ static void recipe_frameset_test_frameset_diff(const cpl_frameset * self,
             continue;
         }
 
-        for (;cmp != NULL; cmp = cpl_frameset_get_next_const(other)) {
+        cmp = irplib_frameset_get_first_const(&it2, other);
+        for (;cmp != NULL; cmp = irplib_frameset_get_next_const(it2)) {
             const char * cfile = cpl_frame_get_filename(cmp);
 
             if (!strcmp(file, cfile)) break;
 
         }
+        cpl_frameset_iterator_delete(it2);
+        it2 = NULL;
         if (cmp == NULL) {
             /* frame is new */
 
@@ -1269,4 +1280,6 @@ static void recipe_frameset_test_frameset_diff(const cpl_frameset * self,
             recipe_frameset_test_frame(frame);
         }
     }
+
+    cpl_frameset_iterator_delete(it1);
 }
