@@ -955,7 +955,7 @@ irplib_dfs_table_convert(cpl_table               * self,
     1) How to parse the lines - each line is read with fgets().
     2) For each column: type/format (%lg/%s/%d) + label
 
-  During a succesful call self will have rows added or removed to exactly
+  During a successful call self will have rows added or removed to exactly
   match the number of lines converted. Any a priori knowledge about the
   expected number of converted rows can be used in the creation of the
   table (to reduce memory reallocation overhead).
@@ -1004,6 +1004,7 @@ irplib_table_read_from_frameset(cpl_table               * self,
     int                nrow       = cpl_table_get_nrow(self);
     int                irow       = 0;
     cpl_errorstate     prestate   = cpl_errorstate_get();
+    cpl_frameset_iterator * iterator = NULL;
 
     cpl_ensure_code(self         != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(useframes    != NULL, CPL_ERROR_NULL_INPUT);
@@ -1013,9 +1014,9 @@ irplib_table_read_from_frameset(cpl_table               * self,
 
     linebuffer = cpl_malloc(maxlinelen);
 
-    for (rawframe = cpl_frameset_get_first_const(useframes);
+    for (rawframe = irplib_frameset_get_first_const(&iterator, useframes);
          rawframe != NULL;
-         rawframe = cpl_frameset_get_next_const(useframes), nfiles++) {
+         rawframe = irplib_frameset_get_next_const(iterator), nfiles++) {
 
         const char * rawfile = cpl_frame_get_filename(rawframe);
         const char * done; /* Indicate when the reading is done */
@@ -1093,6 +1094,7 @@ irplib_table_read_from_frameset(cpl_table               * self,
                             1+nfiles, rawfile);
     }
 
+    cpl_frameset_iterator_delete(iterator);
     cpl_free(linebuffer);
     if (stream != NULL) fclose(stream);
 
@@ -1215,13 +1217,16 @@ cpl_frame * irplib_frameset_get_first_from_group(const cpl_frameset * self,
                                                  cpl_frame_group      group)
 {
     const cpl_frame * frame;
+    cpl_frameset_iterator * iterator = NULL;
 
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
-    for (frame = cpl_frameset_get_first_const(self); frame != NULL ;
-         frame = cpl_frameset_get_next_const(self)) {
+    for (frame = irplib_frameset_get_first_const(&iterator, self);
+         frame != NULL ;
+         frame = irplib_frameset_get_next_const(iterator)) {
         if (cpl_frame_get_group(frame) == group) break;
     }
+    cpl_frameset_iterator_delete(iterator);
     return frame;
 }
 
@@ -1535,16 +1540,18 @@ cpl_error_code irplib_frameset_sort(const cpl_frameset *  self, int* iindex, dou
 	const cpl_frame* tmp_frame = 0;
 	cpl_error_code error = CPL_ERROR_NONE;
 	sz = cpl_frameset_get_size(self);
+	cpl_frameset_iterator* iterator = NULL;
 
 	/* 1. get an array of frames */
-	tmp_frame = cpl_frameset_get_first_const(self);
+	tmp_frame = irplib_frameset_get_first_const(&iterator, self);
 	while(tmp_frame)
 	{
 		exptime[i] = frame_get_exptime(tmp_frame);
 		iindex[i] = i;
-		tmp_frame = cpl_frameset_get_next_const(self);
+		tmp_frame = irplib_frameset_get_next_const(iterator);
 		i++;
 	}
+	cpl_frameset_iterator_delete(iterator);
 	/* 2.sort */
 	quicksort(iindex, exptime, 0, sz - 1);
 
@@ -1678,3 +1685,51 @@ void irplib_aligned_free (void * aligned_ptr)
       free (*(((void **) aligned_ptr) - 1));
 #endif
 }
+
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief Return the first frame in a frameset using the iterator API.
+  @param[out]  iterator  Location of frameset iterator pointer that will be
+        filled with a new iterator instance for subsequent calls to the function
+        @c irplib_frameset_get_next_const.
+  @param[in]   frameset  The frameset to iterate over.
+  @return The first frame in the frameset or NULL on error.
+  @note The iterator instance returned in the @a iterator pointer must be
+        cleaned up with a call to @c cpl_frameset_iterator_delete. If an error
+        occurred and a new iterator instance was not created then @c *iterator
+        will be set to NULL and need not be cleaned up.
+ */
+/*----------------------------------------------------------------------------*/
+const cpl_frame *
+irplib_frameset_get_first_const(cpl_frameset_iterator **iterator,
+                                const cpl_frameset *frameset)
+{
+    cpl_ensure(iterator != NULL, CPL_ERROR_NULL_INPUT, NULL);
+    *iterator = cpl_frameset_iterator_new(frameset);
+    return cpl_frameset_iterator_get_const(*iterator);
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief Return the next frame in a frameset using the iterator API.
+  @param[in]  iterator  Iterator instance that was returned in an initial call
+                        to @c _irplib_frameset_get_first_const.
+  @return The next frame in the frameset or NULL if already at the end of the
+          list. NULL is also returned if an error occurred which can be checked
+          with a call to @c cpl_error_get_code.
+ */
+/*----------------------------------------------------------------------------*/
+const cpl_frame *
+irplib_frameset_get_next_const(cpl_frameset_iterator *iterator)
+{
+    cpl_errorstate prestate = cpl_errorstate_get();
+    cpl_error_code error = cpl_frameset_iterator_advance(iterator, 1);
+    if (error == CPL_ERROR_ACCESS_OUT_OF_RANGE) {
+        cpl_errorstate_set(prestate);
+        return NULL;
+    } else if (error != CPL_ERROR_NONE) {
+        return NULL;
+    }
+    return cpl_frameset_iterator_get_const(iterator);
+}
