@@ -2,24 +2,29 @@ def log_invocation(fn='/tmp/reflex_invoc.log'):
     """ log invocation of actor for easy reexecution with:
         eval $(cat /tmp/reflex_invoc.log)
     """
-    import sys
-    #import os
+    import os, sys
     #if 'REFLEX_DEBUG' not in os.environ:
     #    return
     try:
         with open(fn, 'w') as f:
+            path = ""
             s = " ".join(['"%s"' % x for x in sys.argv])
-            f.write('python ' + s + '\n')
+            try:
+                import reflex
+                path = '"%s:"' % os.path.dirname(reflex.__file__)
+            except ImportError:
+                pass
+            f.write('PYTHONPATH=%s$PYTHONPATH python %s\n' % (path, s)) 
     except:
         pass
 
 
+
+
 # import the needed modules
 try:
-  import numpy
-  import pyfits
-  import wx
   import matplotlib
+  import reflex_plot_widgets
   from pipeline_product import *
   matplotlib.use('WXAgg')
   import_sucess = 'true'
@@ -57,10 +62,10 @@ try:
     def readFitsData(self, fitsFiles):
       #Control variable to ced_heck if the interesting files where at the input
       self.red_sci_point_mos_found = False
+      self.sci_info_tab_mos_found = False
       self.cubify = False
 
       #Read all the products
-      hdus = dict()
       from collections import defaultdict
       frames = defaultdict(list)
 
@@ -68,55 +73,66 @@ try:
       list_hdus_sci_redu = list()
       list_hdus_err_sci_redl = list()
       list_hdus_err_sci_redu = list()
+      list_hdus_sci_info_tab_redu = list()
       list_sci_redl = list()
       list_sci_redu = list()
       list_err_sci_redl = list()
       list_err_sci_redu = list()
+      list_sci_info_tab_redl = list()
+      list_sci_info_tab_redu = list()
 
       for frame in fitsFiles:
         if frame == '' :
           continue
         pipe_product = PipelineProduct(frame)
-        hdulist = pipe_product.hdulist()
-  
+        hdulist = pipe_product.hdulist()  
         hdus_item = dict()
         #hdulist = frame.hdulist()
         category = frame.category
         frames[category].append(frame)
-                    
+        #print category, frame.name
 
-
-
-
-        print category, frame.name
         if category == "MWXB_SCI_REDL" :
            list_sci_redl.append(frame)
            hdus_item[category]=hdulist
            list_hdus_sci_redl.append(hdus_item[category])
-
-           
            #print category
+
         elif category == "MWXB_SCI_REDU" :
            list_sci_redu.append(frame)
            hdus_item[category]=hdulist
            list_hdus_sci_redu.append(hdus_item[category])
            #print category
 
-
         elif category == "ERR_MWXB_SCI_REDL" :
            list_err_sci_redl.append(frame)
            hdus_item[category]=hdulist
-           list_hdus_err_sci_redl.append(hdus_item[category])
-
-           
+           list_hdus_err_sci_redl.append(hdus_item[category])           
            #print category
+
         elif category == "ERR_MWXB_SCI_REDU" :
            list_err_sci_redu.append(frame)
            hdus_item[category]=hdulist
            list_hdus_err_sci_redu.append(hdus_item[category])
            #print category
 
+        elif category == "FIB_SCI_INFO_TAB_REDL":
+           self.sci_info_tab_mos_found = True  
+           list_sci_info_tab_redl.append(frame)
+           hdus_item[category]=hdulist
+           hdu_sci_info_tab_redl = hdus_item[category]
 
+           #get WLEN and SIMCAL setting
+           table = pipeline_product.PipelineProduct(frame)
+           self.wlen = table.all_hdu[0].header['ESO INS GRAT2 WLEN']
+           self.is_simcal = table.all_hdu[0].header['ESO OCS SIMCAL']
+
+        elif "FIB_SCI_INFO_TAB_REDU" in frames :
+           self.sci_info_tab_mos_found = True  
+           list_sci_info_tab_redu.append(frame)
+           hdus_item[category]=hdulist
+           list_hdus_sci_info_tab_redu.append(hdus_item[category])
+ 
       naxis=list_hdus_sci_redl[0][0].header['NAXIS']
       if  naxis == 2  :
           nf = list_hdus_sci_redl[0].data.shape[0]
@@ -126,30 +142,87 @@ try:
           nf = len(list_sci_redl)
           print "Sci fibre normal format"
       
-      print "nf=", nf , "cubify = ", self.cubify
+      #print "nf=", nf , "cubify = ", self.cubify
 
-      #nf=4
       self.nfibres = nf
       self.list_spec_raw = []
-      print "nf=",nf
+      self.list_snr_raw = []
+      #i=1
+  
+      # Read fibre info table a first time to know if the fibre is a
+      # simultaneous calibration fibre or allocated to object or sky
+      self.list_obs_obj_cal = []
+      self.list_obs_obj_type = []
+      for i in range(9):
+         self.list_obs_obj_cal.append(hdu_sci_info_tab_redl[1].data['Retractor_pt1'][i])
+         self.list_obs_obj_type.append(hdu_sci_info_tab_redl[1].data['TYPE'][i])
+
+     
+      # Read fibre info table a second time to get object id and
+      # corresponding RA,DEC only for simultaneous calibration fibre
+      # and fibres allocated to object or sky      
+      self.list_obs_objects = []
+      self.list_obs_obj_ra = []
+      self.list_obs_obj_dec = []
+      for i in range(9):
+         if self.list_obs_obj_cal[i] == "Calibration"  and self.is_simcal == 1 :
+           self.list_obs_objects.append(hdu_sci_info_tab_redl[1].data['OBJECT'][i])
+
+           self.list_obs_obj_ra.append(hdu_sci_info_tab_redl[1].data['RA'][i])
+           self.list_obs_obj_dec.append(hdu_sci_info_tab_redl[1].data['DEC'][i])
+    
+         if self.list_obs_obj_type[i] == "U" or self.list_obs_obj_type[i] == "S" :
+           self.list_obs_objects.append(hdu_sci_info_tab_redl[1].data['OBJECT'][i])
+           self.list_obs_obj_ra.append(hdu_sci_info_tab_redl[1].data['RA'][i])
+           self.list_obs_obj_dec.append(hdu_sci_info_tab_redl[1].data['DEC'][i])
+          
+           
+      #print self.list_obs_objects
+
+      self.list_used_fibres = []
       for i in range(nf):
+        #table=list_hdus_sci_info_tab_redl[0].data[i,:]
         self.red_sci_point_mos_found = True
         if self.cubify == True :
-           import pdb
-           pdb.set_trace()
-           spettra_l=list_hdus_sci_redl[0][i].data[:];
+           print "cube case"
+           #import pdb
+           #pdb.set_trace()
            self.list_spec_raw.append(UvesRedSpectrum(list_hdus_sci_redl[0].data[i,:],list_hdus_sci_redu[0].data[i,:],list_hdus_err_sci_redl[0].data[i,:],list_hdus_err_sci_redu[0].data[i,:]))
         else :
+           #print "normal case i=",i,self.list_obs_obj_cal[i],self.list_obs_obj_type[i]
+           self.list_used_fibres.append(i)
+
+           #print "add to list",  i,self.list_obs_objects[i] 
            self.list_spec_raw.append(FlamesUvesSpectrum(frames["MWXB_SCI_REDL"],
                                                   frames["MWXB_SCI_REDU"],i,
                                                   frames["ERR_MWXB_SCI_REDL"],
                                                   frames["ERR_MWXB_SCI_REDU"]))
-
-          # self.list_spec_raw.append(UvesRedSpectrum(list_hdus_sci_redl[i],
-          #                                        list_hdus_sci_redu[i],
-          #                                        list_hdus_err_sci_redl[i],
-          #                                        list_hdus_err_sci_redu[i]))
+           #self.list_snr_raw.append(FlamesUvesSN(frames["MWXB_SCI_REDL"],
+           #                                       frames["MWXB_SCI_REDU"],i,
+           #                                       frames["ERR_MWXB_SCI_REDL"],
+           #                                       frames["ERR_MWXB_SCI_REDU"]))
+ 
         #print "no of fibres", self.nfibres
+        #print "allocated fibres", self.list_used_fibres
+
+
+    def plotWidgets(self) :
+        widgets = list()
+        #labels= [0,1,2,3,4,5,6,7]
+        labels = self.list_used_fibres
+        # Files Selector radiobutton
+        self.radiobutton = reflex_plot_widgets.InteractiveRadioButtons(self.fibre_selector, self.setFibreSelectCallBack, labels, 0, 
+                title="")
+        widgets.append(self.radiobutton)
+
+        return widgets
+
+    def setFibreSelectCallBack(self, fibre_id) :
+        fibre_id = int(fibre_id)
+        self.list_subplot_spec[0].cla()
+        #self.list_subplot_snr[0].cla()
+        #print self.list_spec_raw[fibre_id]
+        self.plotData(fibre_id)
 
     # This function creates all the subplots. It is responsible for the plotting 
     # layouts. 
@@ -157,24 +230,68 @@ try:
     # Note that subplot(I,J,K) means the Kth plot in a IxJ grid 
     # Note also that the last one is actually a box with text, no graphs.
     def addSubplots(self, figure):
+      #gs = gridspec.GridSpec(3, 1)
+      #self.fibre_selector = figure.add_subplot(gs[0,0])
       if self.red_sci_point_mos_found == True :
         self.list_subplot_spec     = []
-        #self.list_subplot_sn       = []
-        #self.list_subplot_fwhm     = []
-        #self.list_subplot_ripple   = []
-        #self.list_subplot_linepos  = []
+        self.list_subplot_snr       = []
+
         nc=1
         nf=self.nfibres
+        nraws=2
         #print "nf=",nf
-        for i in range(nf) :
-          self.list_subplot_spec.append(figure.add_subplot(nf,nc,nc*i+1))
-          #self.list_subplot_sn.append(figure.add_subplot(nf,nc,nc*i+3))
-          #self.list_subplot_fwhm.append(figure.add_subplot(nf,nc,nc*i+4))
-          #self.list_subplot_ripple.append(figure.add_subplot(nf,nc,nc*i+5))
-          #self.list_subplot_linepos.append(figure.add_subplot(nf,nc,nc*i+6))
+        i=self.list_used_fibres[0]
+        #for i in range(nf) :
+        self.list_subplot_spec.append(figure.add_subplot(nraws,nc,nc*i+1))
+        #self.list_subplot_snr.append(figure.add_subplot(nraws,nc,nc*i+2))
+
       else : 
         self.subtext_nodata     = figure.add_subplot(1,1,1)
-          
+        
+      #self.fibre_selector = figure.add_axes([0.85, 0.85, 0.14, 0.14])
+      self.fibre_selector = figure.add_axes([0.85, 0.25, 0.14, 0.14])
+      tip="Frame Id:\n (Mouse \n left\n button)"
+      self.fibre_selector.text(0.35, 0.50, tip, color='black', fontsize=12, ha='left', va='center', alpha=1.0)
+    def plotData(self,fibre_id):
+        self.setInfoObj(fibre_id)
+        self.plotSpectrum(fibre_id)
+        #self.plotSNRSpectrum(fibre_id)
+
+    def setInfoCommon(self):
+        self.title_common   = 'Extracted and Merged Spectrum (REDL,REDU).\n'
+
+        self.title_snr   = 'Signal to Noise Ratio of Extracted and Merged Spectrum (REDL,REDU)' 
+        self.tooltip_spec = """Plot of the extracted and merged spectrum of the science object (blue line) as total flux (ADU) versus wavelength (Ang). 
+The +-1 sigma uncertainties are plotted as the light blue region encompassing the object spectrum (and bounded by the light grey spectra). 
+Note that this spectrum is not flux calibrated."""
+
+        self.tooltip_snr = """Plot of the Signal to Noise ratio associated to the extracted and merged spectrum of the science object (blue line) as total flux (ADU) versus wavelength (Ang). 
+The +-1 sigma uncertainties are plotted as the light blue region encompassing the object spectrum (and bounded by the light grey spectra). 
+Note that this spectrum is not flux calibrated."""
+
+    def setInfoSetting(self):
+        if self.is_simcal == 1 :
+           self.info_setting = 'SimCal %#.3d mode. '% (self.wlen) 
+        else :
+           self.info_setting = 'OzPoz %#.3d mode. '% (self.wlen) 
+
+    def setInfoObj(self,fibre_id):
+        if self.list_obs_obj_cal[fibre_id] == "Calibration" and self.is_simcal == 1 :
+           self.info_obj='Simultaneous calibration fibre'
+        else :
+           self.info_obj='Target: '+self.list_obs_objects[fibre_id]+' RA=%#.4g DEC=%#.4g'% (self.list_obs_obj_ra[fibre_id],self.list_obs_obj_dec[fibre_id])
+
+    def plotSpectrum(self,fibre_id):
+        self.title_spec=self.title_common+self.info_setting+self.info_obj
+        title=self.title_spec
+        tooltip=self.tooltip_spec
+        self.list_spec_raw[fibre_id].plot(self.list_subplot_spec[0], title, tooltip)
+
+    def plotSNRSpectrum(self,fibre_id):
+        title=self.title_snr
+        tooltip=self.tooltip_snr
+        self.list_snr_raw[fibre_id].plot(self.list_subplot_snr[0], title, tooltip)
+
     # This is the function that makes the plots.
     # Add new plots or delete them using the given scheme.
     # The data has been already stored in self.plot_x, self.plot_xdif, etc ...
@@ -182,30 +299,18 @@ try:
     # One might be tempted to merge addSubplots() and plotProductsGraphics().
     # There is a reason not to do it: addSubplots() is called only once at
     # startup, while plotProductsGraphics() is called always there is a resize.
-    def plotProductsGraphics(self, figure, canvas):
+    def plotProductsGraphics(self):
       if self.red_sci_point_mos_found == True :
-        nf=self.nfibres
-        for i in range(nf) :
-          #print "fill i=",i
-          #First subpanel: a spectrum
-          if self.red_sci_point_mos_found == True :
-            title_spec   = 'Extracted and Merged Spectrum (REDL,REDU) Fib: %d'% (i) 
-            tooltip_spec = """Plot of the extracted and merged spectrum of the science object (blue line) as total flux (ADU) versus wavelength (Ang). 
-The +-1 sigma uncertainties are plotted as the light blue region encompassing the object spectrum (and bounded by the light grey spectra). 
-Note that this spectrum is not flux calibrated."""
-            self.list_spec_raw[i].plot(self.list_subplot_spec[i], title_spec, tooltip_spec)
+        i=self.list_used_fibres[0] 
 
-            #Second subpanel: a plot
+        #First subpanel: a spectrum
+        if self.red_sci_point_mos_found == True :
+           self.setInfoCommon()
+           self.setInfoSetting()
+           self.setInfoObj(i)
+           self.plotData(i)
 
-            #Third subpanel: a plot
 
-            #Fourth subpanel: a plot
-
-            #Fifth subpanel: a plot
-            if self.red_sci_point_mos_found == True :
-              #self.subplot_linepos.set_ylim(0., self.list_spec_raw[i].qc_ex_ysize_low)
-              #print 'nothing to do'
-              continue
       else :
         #Data not found info
         self.subtext_nodata.set_axis_off()
@@ -312,6 +417,7 @@ Attempt to optimise the S/N of the extracted spectrum as a function of spectral
       title = 'Uves Interactive Spectrum Extraction'
       return title
 
+
 except ImportError:
   import_sucess = 'false'
   print "Error importing modules pyfits, wx, matplotlib, numpy"
