@@ -10,7 +10,7 @@ class Plot:
 
   def finalSetup(self, subplot, title, tooltip):
     subplot.grid(True)
-    subplot.set_title(title, fontsize=8)
+    subplot.set_title(title, fontsize=11)
     subplot.tooltip = tooltip
 
 
@@ -68,13 +68,59 @@ class FlamesUvesSpectrum:
     flux_plotmax           = max(flux_low_plotmax, flux_high_plotmax)
     subplot.set_ylim(flux_plotmin,flux_plotmax)
 
+
+
+
+
+class FlamesUvesSN:
+  def __init__(self, fits_low, fits_high,fib_id, 
+               fits_low_err, fits_high_err):
+    self.spec_low  = pipeline_product.PipelineProduct(fits_low[fib_id])
+    self.spec_high = pipeline_product.PipelineProduct(fits_high[fib_id])
+    self.spec_low_err  = pipeline_product.PipelineProduct(fits_low_err[fib_id])
+    self.spec_high_err = pipeline_product.PipelineProduct(fits_high_err[fib_id])
+    self.loadFromFits()
+    self.specdisp = pipeline_display.SpectrumDisplay()
+
+  def loadFromFits(self) :
+    self.spec_low.readSpectrum()
+    self.spec_high.readSpectrum()
+    self.spec_low_err.readSpectrum()
+    self.spec_high_err.readSpectrum()
+  
+
+  def plot(self, subplot, title, tooltip):
+    self.specdisp.setLabels(self.spec_low.type1,
+                           '['+self.spec_low.bunit+']')
+    import numpy as np
+    np.save('/tmp/data1.npy', self.spec_low.flux)
+    np.save('/tmp/data2.npy', self.spec_low_err.flux)
+    self.specdisp.display(subplot, title, tooltip, 
+                            self.spec_low.wave, 
+                            self.spec_low.flux / self.spec_low_err.flux, 
+                            autolimits=True)
+    (flux_low_plotmin, flux_low_plotmax)   = self.specdisp.flux_lim
+    self.specdisp.display(subplot, title, tooltip, 
+                            self.spec_high.wave, 
+                            self.spec_high.flux /  self.spec_high_err.flux,
+                            autolimits=True)
+    (flux_high_plotmin, flux_high_plotmax) = self.specdisp.flux_lim
+      
+    subplot.set_xlim(min(self.spec_low.start_wave, self.spec_high.start_wave),
+                     max(self.spec_low.end_wave, self.spec_high.end_wave))
+    flux_plotmin           = min(flux_low_plotmin, flux_high_plotmin) 
+    flux_plotmin           = min(flux_plotmin, 0) 
+    flux_plotmax           = max(flux_low_plotmax, flux_high_plotmax)
+    subplot.set_ylim(flux_plotmin,flux_plotmax)
+
+
 class ScatterPlot(Plot):
   def __init__(self, fits):
     self.loadFromFits(fits)
 
   def scatterPlot(self, subplot, x, y, x_label, y_label, title, tooltip):
     self.scatterPlotScatter(subplot, x, y)
-    self.setLabels(subplot, x_label, y_label,fontsize=8)
+    self.setLabels(subplot, x_label, y_label,fontsize=11)
     self.scatterPlotLimits(subplot, x, y)
     self.finalSetup(subplot, title, tooltip)
 
@@ -84,7 +130,7 @@ class ScatterPlot(Plot):
   def scatterPlotScatterSmall(self, subplot, x, y, color_pt='blue'):
     subplot.scatter(x, y, s=0.5, color=color_pt)
 
-  def setLabels(self, subplot, x_label, y_label, fontsize=8):
+  def setLabels(self, subplot, x_label, y_label, fontsize=11):
     subplot.set_xlabel(x_label,fontsize=fontsize)
     subplot.set_ylabel(y_label,fontsize=fontsize)
 
@@ -500,15 +546,16 @@ class PlotableRedLineGuessTable(ScatterPlot):
     self.finalSetup(subplot, title, tooltip)
 
 class PlotableLineTable(ScatterPlot):
-  def __init__(self, fits,fib_id):
+  def __init__(self, fits,ext_id,fib_id):
     self.table = pipeline_product.PipelineProduct(fits)
-    self.loadFromFits(self.table,fib_id+1)
+    self.loadFromFits(self.table,ext_id,fib_id)
   
-  def loadFromFits(self, table,fib_id) :
+  def loadFromFits(self, table,ext_id,fib_id) :
     n_win                = (table.all_hdu.__len__() - 1 )//3
-    id_win               = (n_win+1)//2
-    ext_id               = 3 * (id_win -1 ) + 1
-    #print 'ext_id=',ext_id,'w_win=',n_win
+    #id_win               = (n_win+1)//2
+    #id_win               = (fib_id+1)//2
+    #ext_id               = 3 * (id_win -1 ) + 1
+    #print 'ext_id=',ext_id,'n_win=',n_win, "fib_id=",fib_id
     self.x_raw           = table.all_hdu[ext_id].data.field('X')
     self.ynew_raw        = table.all_hdu[ext_id].data.field('Ynew')
     self.residual_raw    = table.all_hdu[ext_id].data.field('Residual')
@@ -521,9 +568,9 @@ class PlotableLineTable(ScatterPlot):
     self.nlintot = 0
     self.nlinsel = 0
     self.nlinsol = 0
-    #self.nlintot         = table.all_hdu[0].header['ESO QC FIB%d NLINTOT' % fib_id]
-    #self.nlinsel         = table.all_hdu[0].header['ESO QC FIB%d NLINSEL' % fib_id]
-    #self.nlinsol         = table.all_hdu[0].header['ESO QC FIB%d NLINSOL' % fib_id] 
+    self.nlintot         = table.all_hdu[0].header['ESO QC FIB%d NLINTOT' % fib_id]
+    self.nlinsel         = table.all_hdu[0].header['ESO QC FIB%d NLINSEL' % fib_id]
+    self.nlinsol         = table.all_hdu[0].header['ESO QC FIB%d NLINSOL' % fib_id] 
     self.fwhm            = self.xwidth_raw * 2.35
     self.fwhm_sel        = self.fwhm[self.select_raw == 1]
     self.fwhm_clean      = self.fwhm_sel[numpy.isfinite(self.fwhm_sel)]
@@ -547,7 +594,7 @@ class PlotableBlueLineTable(PlotableLineTable):
   def plotRESvsWAVE(self, subplot, title, tooltip) :
     self.scatterPlotScatterSmall(subplot, self.wavec_raw, self.residual_raw, color_pt='red')
     self.scatterPlotScatterSmall(subplot, self.wavec_sel, self.residual_sel)
-    self.setLabels(subplot, 'Wavelength [Ang]', 'Wavelength Residual  [Ang]',fontsize=8)
+    self.setLabels(subplot, 'Wavelength [Ang]', 'Wavelength Residual  [Ang]',fontsize=11)
 
     subplot.set_xlim(self.min_wavec, self.max_wavec)
     subplot.axhline(y=self.median_residual, color='black', lw=1.2)
@@ -595,12 +642,19 @@ class PlotableBlueLineTable(PlotableLineTable):
      subplot.tooltip='Lines info'
 
 class PlotableMosLineTable(ScatterPlot):
-  def __init__(self, fits_low, fits_high,fib_id = None):
-    self.tab_low              = PlotableLineTable(fits_low,fib_id)
-    self.tab_high             = PlotableLineTable(fits_high,fib_id)
-    self.min_wavec            = min(self.tab_low.min_wavec, self.tab_high.min_wavec)
-    self.max_wavec            = max(self.tab_low.max_wavec, self.tab_high.max_wavec)
-    self.median_all_residual  = numpy.median(numpy.concatenate((self.tab_low.residual_sel, self.tab_high.residual_sel)))
+  def __init__(self, fits_low, fits_high,ext_id=None, fib_id=None, fib_cnt=None):
+
+
+    #self.min_wavec = []
+    #self.max_wavec = []
+    #self.median_all_residual = []
+
+    self.tab_low              = PlotableLineTable(fits_low,ext_id,fib_id)
+    self.tab_high             = PlotableLineTable(fits_high,ext_id,fib_id)
+    #print "flames_plot_common: fib_id=",fib_id,"fib_cnt=",fib_cnt
+    self.min_wavec = min(self.tab_low.min_wavec, self.tab_high.min_wavec)
+    self.max_wavec = max(self.tab_low.max_wavec, self.tab_high.max_wavec)
+    self.median_all_residual = numpy.median(numpy.concatenate((self.tab_low.residual_sel, self.tab_high.residual_sel)))
     self.mean_all_residual    = numpy.mean(numpy.concatenate((self.tab_low.residual_sel, self.tab_high.residual_sel)))
     self.std_all_residual     = numpy.std(numpy.concatenate((self.tab_low.residual_sel, self.tab_high.residual_sel)))
     self.median_all_fwhm      = numpy.median(numpy.concatenate((self.tab_low.fwhm_sel, self.tab_high.fwhm_sel)))
@@ -614,7 +668,7 @@ class PlotableMosLineTable(ScatterPlot):
     self.x_raw_shift          = self.tab_high.x_raw + self.tab_low.det_ny
     self.y_sel_shift          = self.tab_high.ynew_sel + self.tab_low.det_nx
     self.y_raw_shift          = self.tab_high.ynew_raw + self.tab_low.det_nx
-
+    #print "fib id",fib_id,"median",self.median_all_residual
   def plotGridLowHiTextRight(self, grid):
     grid[0].text(0.9, 0.9, "RedHi", transform = grid[0].transAxes,
                  ha="right",va="top",size=13,bbox=dict(boxstyle="round",alpha=0.2))
@@ -639,13 +693,14 @@ class PlotableMosLineTable(ScatterPlot):
     subplot.text(0.9, 0.9, "RedHi", transform = subplot.transAxes,
                  ha="right",va="top",size=13,bbox=dict(boxstyle="round",alpha=0.2))
 
-  def plotRESvsWAVE(self, subplot, title, tooltip) :
+  def plotRESvsWAVE(self, subplot, title, tooltip,fibre_id=None) :
     self.plotLowHiTextTop(subplot)
     self.setLabels(subplot, 'Wavelength [Ang]', 'Wave Resid [Ang]')
     self.scatterPlotScatterSmall(subplot, self.tab_low.wavec_raw, self.tab_low.residual_raw, color_pt='red')
     self.scatterPlotScatterSmall(subplot, self.tab_low.wavec_sel, self.tab_low.residual_sel)
     self.scatterPlotScatterSmall(subplot, self.tab_high.wavec_raw, self.tab_high.residual_raw, color_pt='red')
     self.scatterPlotScatterSmall(subplot, self.tab_high.wavec_sel, self.tab_high.residual_sel)
+    #print "plotRESvsWAVE: fibre_id=",fibre_id
     subplot.set_xlim(self.min_wavec, self.max_wavec)
     subplot.axhline(y=self.median_all_residual, color='black', lw=1.2)
     subplot.axhline(y=self.median_all_residual+self.std_all_residual, color='black', ls='-.', lw=1.2)
@@ -653,7 +708,7 @@ class PlotableMosLineTable(ScatterPlot):
     subplot.axvline(linewidth=1.5, color='black', x=(self.tab_low.max_wavec + self.tab_high.min_wavec)/2.)
     self.finalSetup(subplot, title, tooltip)
 
-  def plotRESvsORDER(self, subplot, title, tooltip) :
+  def plotRESvsORDER(self, subplot, title, tooltip,fibre_id=None) :
     self.plotLowHiTextTop(subplot)
     self.setLabels(subplot, 'Order', 'Wave Resid [Ang]')
     self.scatterPlotScatterSmall(subplot, self.tab_low.order_raw, self.tab_low.residual_raw, color_pt='red')
@@ -667,7 +722,7 @@ class PlotableMosLineTable(ScatterPlot):
     subplot.axvline(linewidth=1.5, color='black', x=self.tab_low.max_order + 0.5)
     self.finalSetup(subplot, title, tooltip)
 
-  def plotFWHMvsWAVE(self, subplot, title, tooltip) :
+  def plotFWHMvsWAVE(self, subplot, title, tooltip,fibre_id=None) :
     self.plotLowHiTextTop(subplot)
     self.setLabels(subplot, 'Wavelength [Ang]', 'Line FWHM [pix]')
     self.scatterPlotScatterSmall(subplot, self.tab_low.wavec_raw, self.tab_low.fwhm, color_pt='red')
