@@ -36,7 +36,7 @@
 
 //#include "cpl_init.h"
 //#include "cpl_error.h"
-//#include "uves_propertylist_impl.h"
+//#include "cpl_propertylist_impl.h"
 #include <uves_error.h>
 #include <cpl.h>
 #include <cxmemory.h>
@@ -337,6 +337,7 @@ static int test_main(void)
         {"HISTORY", "3st history record", NULL, CPL_TYPE_STRING},
         {"END", NULL, NULL, CPL_TYPE_STRING}
     };
+    cpl_image* ima;
 
     FILE *file;
     /*
@@ -384,11 +385,11 @@ static int test_main(void)
 
 
     for (i = 0; i < cpl_propertylist_get_size(plist); i++) {
-        cpl_property *p = cpl_propertylist_get(plist, i);
+        cpl_property *prop = cpl_propertylist_get(plist, i);
 
-        cx_assert(!strcmp(cpl_property_get_name(p), keys[i]));
-        cx_assert(!strcmp(cpl_property_get_comment(p), comments[i]));
-        cx_assert(cpl_property_get_type(p) == types[i]);
+        cx_assert(!strcmp(cpl_property_get_name(prop), keys[i]));
+        cx_assert(!strcmp(cpl_property_get_comment(prop), comments[i]));
+        cx_assert(cpl_property_get_type(prop) == types[i]);
 
         cx_assert(my_uves_propertylist_contains(plist, keys[i]));
         cx_assert(!strcmp(cpl_propertylist_get_comment(plist, keys[i]),
@@ -670,56 +671,56 @@ static int test_main(void)
 
 
     for (i = 0; i < cpl_propertylist_get_size(plist); i++) {
-        cpl_property *p = cpl_propertylist_get(plist, i);
-        cpl_property *_p = cpl_propertylist_get(_plist, i);
+        cpl_property *prop = cpl_propertylist_get(plist, i);
+        cpl_property *_prop = cpl_propertylist_get(_plist, i);
 
 
-        cx_assert(cpl_property_get_name(p) != cpl_property_get_name(_p));
-        cx_assert(!strcmp(cpl_property_get_name(p),
-                          cpl_property_get_name(_p)));
-        cx_assert(cpl_property_get_comment(p) == NULL ||
-                  (cpl_property_get_comment(p) !=
-                   cpl_property_get_comment(_p)));
-        cx_assert(cpl_property_get_comment(p) == NULL ||
-                  !strcmp(cpl_property_get_comment(p),
-                          cpl_property_get_comment(_p)));
+        cx_assert(cpl_property_get_name(prop) != cpl_property_get_name(_prop));
+        cx_assert(!strcmp(cpl_property_get_name(prop),
+                          cpl_property_get_name(_prop)));
+        cx_assert(cpl_property_get_comment(prop) == NULL ||
+                  (cpl_property_get_comment(prop) !=
+                   cpl_property_get_comment(_prop)));
+        cx_assert(cpl_property_get_comment(prop) == NULL ||
+                  !strcmp(cpl_property_get_comment(prop),
+                          cpl_property_get_comment(_prop)));
 
-        switch (cpl_property_get_type(p)) {
+        switch (cpl_property_get_type(prop)) {
         case CPL_TYPE_CHAR:
-            cx_assert(cpl_property_get_char(p) ==
-                      cpl_property_get_char(_p));
+            cx_assert(cpl_property_get_char(prop) ==
+                      cpl_property_get_char(_prop));
             break;
 
         case CPL_TYPE_BOOL:
-            cx_assert(cpl_property_get_bool(p) ==
-                      cpl_property_get_bool(_p));
+            cx_assert(cpl_property_get_bool(prop) ==
+                      cpl_property_get_bool(_prop));
             break;
 
         case CPL_TYPE_INT:
-            cx_assert(cpl_property_get_int(p) ==
-                      cpl_property_get_int(_p));
+            cx_assert(cpl_property_get_int(prop) ==
+                      cpl_property_get_int(_prop));
             break;
 
         case CPL_TYPE_LONG:
-            cx_assert(cpl_property_get_long(p) ==
-                      cpl_property_get_long(_p));
+            cx_assert(cpl_property_get_long(prop) ==
+                      cpl_property_get_long(_prop));
             break;
 
         case CPL_TYPE_FLOAT:
-            fval[0] = cpl_property_get_float(p);
-            fval[1] = cpl_property_get_float(_p);
+            fval[0] = cpl_property_get_float(prop);
+            fval[1] = cpl_property_get_float(_prop);
             cx_assert(!memcmp(&fval[0], &fval[1], sizeof(float)));
             break;
 
         case CPL_TYPE_DOUBLE:
-            dval[0] = cpl_property_get_double(p);
-            dval[1] = cpl_property_get_double(_p);
+            dval[0] = cpl_property_get_double(prop);
+            dval[1] = cpl_property_get_double(_prop);
             cx_assert(!memcmp(&dval[0], &dval[1], sizeof(double)));
             break;
 
         case CPL_TYPE_STRING:
-            cx_assert(!strcmp(cpl_property_get_string(p),
-                              cpl_property_get_string(_p)));
+            cx_assert(!strcmp(cpl_property_get_string(prop),
+                              cpl_property_get_string(_prop)));
             break;
 
         default:
@@ -752,8 +753,8 @@ static int test_main(void)
     cx_assert(cpl_propertylist_get_size(plist) == 7);
 
     for (i = 0; i < 7; i++) {
-        cpl_property *p = cpl_propertylist_get(plist, i);
-        cx_assert(!strcmp(cpl_property_get_name(p), keys[i]));
+        cpl_property *prop = cpl_propertylist_get(plist, i);
+        cx_assert(!strcmp(cpl_property_get_name(prop), keys[i]));
     }
 
     if (0) test_plist_dump(plist);
@@ -886,7 +887,7 @@ static int test_main(void)
     cpl_propertylist_save(header,"cpltest1.fits",CPL_IO_CREATE);
  
 
-    cpl_image* ima=cpl_image_new(2148,2340,CPL_TYPE_FLOAT);
+    ima=cpl_image_new(2148,2340,CPL_TYPE_FLOAT);
     check_nomsg(  cpl_error_get_code()   );
     cpl_image_save(ima,"cpltest1.fits",CPL_BPP_16_SIGNED,header,CPL_IO_DEFAULT);
 
@@ -907,8 +908,8 @@ static int test_main(void)
 
  
     cpl_msg_info(cpl_func,"size plist=%" CPL_SIZE_FORMAT "",cpl_propertylist_get_size(plist));
-    cpl_msg_info(cpl_func,"size hdr=%d",sizeof hdr);
-    cpl_msg_info(cpl_func,"size fcard=%d",sizeof(struct fcard));
+    cpl_msg_info(cpl_func,"size hdr=%ld",sizeof hdr);
+    cpl_msg_info(cpl_func,"size fcard=%ld",sizeof(struct fcard));
 
     check_nomsg(  cpl_error_get_code()   );
     //cx_assert(cpl_propertylist_get_size(plist) ==
@@ -980,6 +981,11 @@ static int test_main(void)
      *          verify that the original property list and the one created
      *          from the FITS header are identical.
      */
+
+    /* AMO: Suppressed unit test as cpl_propertylist_from_fitsfile is a CPL
+            internal function that should not be accessed.
+            Still leave the code.
+
     fitsfile* fits_file=NULL; 
     cxint status = 0;
 
@@ -1034,7 +1040,7 @@ static int test_main(void)
 
     check_nomsg(  cpl_error_get_code()   );
 
-
+    */
 
 
     /*
@@ -1226,11 +1232,11 @@ static int test_main(void)
     cx_assert(cpl_propertylist_get_size(_plist) == 3);
 
     for (i = 0; i < cpl_propertylist_get_size(plist); i++) {
-        cpl_property *p = cpl_propertylist_get(plist, i);
+        cpl_property *prop = cpl_propertylist_get(plist, i);
 
-        cx_assert(!strcmp(cpl_property_get_name(p), keys[i]));
-        cx_assert(!strcmp(cpl_property_get_comment(p), comments[i]));
-        cx_assert(cpl_property_get_type(p) == types[i]);
+        cx_assert(!strcmp(cpl_property_get_name(prop), keys[i]));
+        cx_assert(!strcmp(cpl_property_get_comment(prop), comments[i]));
+        cx_assert(cpl_property_get_type(prop) == types[i]);
 
         cx_assert(my_uves_propertylist_contains(plist, keys[i]));
         cx_assert(!strcmp(cpl_propertylist_get_comment(plist, keys[i]),
