@@ -657,9 +657,7 @@ int main(void)
 {
     /* Initialize CPL + UVES messaging */
     cpl_test_init(PACKAGE_BUGREPORT, CPL_MSG_WARNING);
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 0, 0)
     cpl_errorstate initial_errorstate = cpl_errorstate_get();
-#endif
 //    cpl_msg_set_level(CPL_MSG_DEBUG);
 
     check( parse_midas_poly(),
@@ -678,11 +676,7 @@ int main(void)
   cleanup:
     if (cpl_error_get_code() != CPL_ERROR_NONE)
         {
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 0, 0)
 	  cpl_errorstate_dump(initial_errorstate,CPL_FALSE,NULL);
-#else
-            uves_error_dump();
-#endif
         }
     return cpl_test_end(0);
 }
