@@ -101,6 +101,7 @@ uves_response_efficiency(const cpl_image *raw_image,
                          const uves_propertylist *raw_header, 
                          const uves_propertylist *rotated_header,
                          const cpl_image *master_bias,
+                         const uves_propertylist *mbias_header,
                          const cpl_image *master_dark, 
                          const uves_propertylist *mdark_header, 
                          const cpl_table *ordertable, 
@@ -183,6 +184,7 @@ uves_response_efficiency(const cpl_image *raw_image,
                        raw_header, 
                        rotated_header,
                master_bias,
+                      mbias_header,
                master_dark, 
                        mdark_header,
                NULL, 
