@@ -223,6 +223,7 @@ uves_response_process_chip(const cpl_image *raw_image,
                            const uves_propertylist *raw_header, 
                            const uves_propertylist *rotated_header,
                const cpl_image *master_bias,
+                           const uves_propertylist *mbias_header,
                const cpl_image *master_dark, 
                            const uves_propertylist *mdark_header, 
                const cpl_image *master_flat, 
@@ -285,6 +286,7 @@ uves_response_process_chip(const cpl_image *raw_image,
                        raw_header, 
                        rotated_header,
                master_bias,
+                       mbias_header,
                master_dark, 
                        mdark_header,
                master_flat, 
@@ -483,6 +485,7 @@ uves_response_process_chip(const cpl_image *raw_image,
                         raw_header, 
                         rotated_header,
                         master_bias,
+                        mbias_header,
                         master_dark, 
                         mdark_header, 
                         ordertable, 
@@ -909,6 +912,7 @@ UVES_CONCAT2X(UVES_RESPONSE_ID,exe)(cpl_frameset *frames,
                                        raw_header[raw_index],  
                        rotated_header[raw_index],
                        master_bias,            /* Calibration */
+                                       master_bias_header,
                        master_dark, 
                                        master_dark_header,
                        master_flat, 
