@@ -154,11 +154,7 @@
 #include <uves_utils_wrappers.h>
 #include <uves_error.h>
 #include <uves_msg.h>
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 0, 0)
 #include <cpl_ppm.h> /* missing from cpl.h */
-#else
-#include <irplib_ppm.h>
-#endif
 #include <uves_qclog.h>
 #include <cpl.h>
 
@@ -1340,17 +1336,10 @@ uves_wavecal_identify_lines_ppm(cpl_table *linetable, const cpl_table *line_refe
 
             uves_free_bivector(&ids);
 
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 0, 0)
             ids = cpl_ppm_match_positions(peaks, lines,
                                           min_disp, max_disp,
                                           tolerance, 
                                           NULL, NULL);
-#else
-            ids = irplib_ppm_match_positions(peaks, lines,
-                                             min_disp, max_disp,
-                                             tolerance);
-#endif
-
 
 
             if (ids == NULL)
